#
# spec file for package tiled
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tiled
Version:        1.11.2
Release:        2.1
Summary:        A tilemap editor
License:        GPL-2.0-or-later
URL:            https://www.mapeditor.org
Source:         https://github.com/mapeditor/tiled/archive/refs/tags/v%{version}.tar.gz
# PATCH-FIX-UPSTREAM https://github.com/mapeditor/tiled/pull/4167
Patch0:         fixed-compile-against-qt-6_8_2.patch
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  karchive-devel
BuildRequires:  qbs
BuildRequires:  qt6-base-common-devel
BuildRequires:  qt6-base-devel
BuildRequires:  qt6-core-devel >= 6.4.2
BuildRequires:  qt6-declarative-devel
BuildRequires:  qt6-declarative-private-devel
BuildRequires:  qt6-gui-devel
BuildRequires:  qt6-linguist-devel
BuildRequires:  qt6-opengl-devel
BuildRequires:  qt6-qml-devel
BuildRequires:  qt6-quickcontrols2-devel
BuildRequires:  qt6-svg-devel
BuildRequires:  shared-mime-info
BuildRequires:  zlib-devel
Recommends:     tmxtools
Provides:       tiled-qt

%description
Tiled is a general purpose tile map editor. It is built to work with
varying game engines, whether your game is an RPG, platformer or
Breakout clone. Tiled is written in C++, using the Qt application
framework.

%package -n tmxtools
Summary:        Commandline Tools for Tiled MapEditor
License:        BSD-2-Clause

%description -n tmxtools
This package contains tmxviewer, a simple application to view Tiled maps
and tmxrasterizer which is also a command line tool.

%prep
%autosetup -p1
# Remove copy of zlib
rm -rf src/zlib

%build
# see gh/mapeditor/tiled#3613 why no --detect
qbs setup-toolchains --type gcc %{_bindir}/g++ gcc
qbs setup-qt %{_bindir}/qmake6 defprof
qbs config defaultProfile defprof
qbs qbs.installPrefix:"%{_prefix}" projects.Tiled.useRPaths:false projects.Tiled.libDir:%{_lib}

%install
qbs install --install-root %{buildroot}

# Clean build artefacts
find -name ".uic" -or -name ".moc" -or -name ".rcc" | xargs rm -rf

# locale files
%find_lang %{name} --with-qt

# Remove duplicates
%fdupes %{buildroot}%{_datadir}

%if 0%{?suse_version} > 1130
%post
%desktop_database_post
%icon_theme_cache_post
%mime_database_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%mime_database_postun
%endif

%files -f %{name}.lang
%license COPYING LICENSE.GPL LICENSE.BSD
%doc AUTHORS NEWS.md README.md
%{_bindir}/%{name}
%{_bindir}/terraingenerator
%{_datadir}/applications/org.mapeditor.Tiled.desktop
%{_datadir}/metainfo/org.mapeditor.Tiled.appdata.xml
%{_datadir}/icons/hicolor/*/mimetypes/application-x-%{name}.*
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%{_datadir}/mime/packages/org.mapeditor.Tiled.xml
%dir %{_datadir}/%{name}/
%dir %{_datadir}/%{name}/translations
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_libdir}/libtiled.so
%{_libdir}/libtilededitor.so
%dir %{_libdir}/tiled
%dir %{_libdir}/tiled/plugins
%{_libdir}/tiled/plugins/libcsv.so
%{_libdir}/tiled/plugins/libdefold.so
%{_libdir}/tiled/plugins/libdefoldcollection.so
%{_libdir}/tiled/plugins/libdroidcraft.so
%{_libdir}/tiled/plugins/libflare.so
%{_libdir}/tiled/plugins/libgmx.so
%{_libdir}/tiled/plugins/libjson.so
%{_libdir}/tiled/plugins/libjson1.so
%{_libdir}/tiled/plugins/liblua.so
%{_libdir}/tiled/plugins/libreplicaisland.so
%{_libdir}/tiled/plugins/librpmap.so
%{_libdir}/tiled/plugins/libtbin.so
%{_libdir}/tiled/plugins/libtengine.so
%{_libdir}/tiled/plugins/libtscn.so
%{_libdir}/tiled/plugins/libyy.so

%files -n tmxtools
%license LICENSE.BSD
%{_bindir}/tmxrasterizer
%{_bindir}/tmxviewer
%{_mandir}/man1/tmxviewer.1%{?ext_man}
%{_mandir}/man1/tmxrasterizer.1%{?ext_man}
%dir %{_datadir}/thumbnailers/
%{_datadir}/thumbnailers/tiled.thumbnailer
%dir %{_datadir}/metainfo/

%changelog
* Sun Mar  9 2025 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Add fixed-compile-against-qt-6_8_2.patch
* Tue Jan 28 2025 Michael Vetter <mvetter@suse.com>
- Update to 1.11.2:
  * YY plugin: Fixed compatibility with GameMaker 2024 (#4132)
  * Fixed crash while handling file reloads without any files opened
  * Fixed crash when closing the last file with multiple custom properties selected
* Sat Jan 11 2025 Michael Vetter <mvetter@suse.com>
- Update to 1.11.1:
  * Releases now ship with support for loading Aseprite images (#4109)
  * Scripting: Added FileFormat.nameFilter
  * Scripting: Added MapEditor.currentBrushChanged signal
  * Scripting: Added tiled.cursor to create mouse cursor values
  * Scripting: Added Tileset.transformationFlags (#3753)
  * Scripting: Added Dialog.addRadioButtonGroup for selecting one of a list of mutually exclusive options (#4107)
  * Scripting: Made currentWangSet and currentWangColorIndex properties writeable (#4105)
  * AutoMapping: Ignore rules with empty input or output regions (#3834)
  * Fixed saving/loading of custom properties set on worlds (#4025)
  * Fixed issue with placing tile objects after switching maps (#3497)
  * Fixed crash when accessing a world through a symlink (#4042)
  * Fixed performance issue when tinting tiles from large tilesets
  * Fixed error reporting when exporting on the command-line (by Shuhei Nagasawa, #4015)
  * Fixed updating of object label when text changes without changing size
  * Fixed minimum value of spinbox in Tile Animation Editor
  * Fixed loading of custom property types in tilesets referenced by tile stamps (#4044)
  * Fixed compile against Qt 6.8
- Drop fix_compile_against_qt_6_8.patch contained in release
* Wed Nov 13 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Don't harcode the g++ version
- Add fix_compile_against_qt_6_8.patch
* Fri Jun 28 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.11.0:
  * Added --project command-line parameter for use when exporting (#3797)
  * Added group layer names in "Move Object to Layer" menu (#3454)
  * Added lock icon to open tabs for which the file is read-only
  * Added Shift modifier to cut when capturing a tile stamp (by kdx2a, #3961)
  * Made adding "Copy" when duplicating optional and disabled by default (#3917)
  * Changed default shortcut for "Save As" to Ctrl+Shift+S and removed shortcut from "Save All" (#3933)
  * Layer names are now trimmed when edited in the UI, to avoid accidental whitespace
  * Scripting: Added API for working with worlds (#3539)
  * Scripting: Added Object.setProperty overload for setting nested values
  * Scripting: Added Tile.image for accessing a tile's image data
  * Scripting: Added Image.copy overload that takes a rectangle
  * Scripting: Added Tileset.imageFileName and ImageLayer.imageFileName
  * Scripting: Added FilePath.localFile and FileEdit.fileName (string alternatives to Qt.QUrl properties)
  * Scripting: Added tiled.color to create color values
  * Scripting: Made Tileset.margin and Tileset.tileSpacing writable
  * Scripting: Restored compatibility for MapObject.polygon (#3845)
  * Scripting: Fixed issues with editing properties after setting class values from script
  * Scripting: Fixed setting/getting object reference values when nested as a class member
  * TMX format: Embedded images are now also supported on tilesets and image layers
  * JSON format: Fixed tile order when loading a tileset using the old format
  * Godot 4 plugin: Added support for exporting objects (by Rick Yorgason, #3615)
  * Godot 4 plugin: Use Godot 4.2 tile transformation flags (by Rick Yorgason, #3895)
  * Godot 4 plugin: Fixed positioning of tile collision shapes (by Ryan Petrie, #3862)
  * GameMaker 2 plugin: Fixed positioning of objects on isometric maps
  * Python plugin: Added support for implementing tileset formats (with Pablo Duboue, #3857)
  * Python plugin: Raised minimum Python version to 3.8
  * Python plugin: Now built against Python 3.12 for Windows 10+
  * tmxrasterizer: Added --hide-object and --show-object arguments (by Lars Luz, #3819)
  * tmxrasterizer: Added --frames and --frame-duration arguments to export animated maps as multiple images (#3868)
  * tmxrasterizer: Fixed --hide/show-layer to work on group layers (#3899)
  * tmxviewer: Added support for viewing JSON maps (#3866)
  * tmxrasterizer/viewer: Fixed loading of XML object templates (with Christian Schaadt, #3977)
  * AutoMapping: Ignore empty outputs per-rule (#3523)
  * Automapping: Added per-input-layer properties for ignoring flip flags (#3803)
  * AutoMapping: Always apply output sets with empty index
  * AutoMapping: Fixed adding of new tilesets used by applied changes
  * Windows: Fixed the support for WebP images (updated to Qt 6.6.1, #3661)
  * Fixed issues related to map and tileset reloading
  * Fixed possible crash after assigning to tiled.activeAsset
  * Fixed the option to resolve properties on export to also resolve class members (#3411, #3315)
  * Fixed terrain tool behavior and terrain overlays after changing terrain set type (#3204, #3260)
  * Fixed mouse handling issue when zooming while painting (#3863)
  * Fixed possible crash after a scripted tool disappears while active
  * Fixed updating of used tilesets after resizing map (#3884)
  * Fixed alignment of shortcuts in action search
  * Fixed object assignment buttons in tile collision editor (#3399)
  * AppImage: Fixed ability to open paths with spaces from the CLI (#3914)
  * AppImage: Updated to Sentry 0.7.6
* Fri Aug  4 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.10.2:
  * Added support for setting custom properties on the project (with dogboydog, #2903)
  * Added feedback when Terrain Brush and Terrain Fill Mode can't find a tile
  * Removed Space and Ctrl+Space shortcuts from Layers view to avoid conflict with panning (#3672)
  * Display the image base name for unnamed tile objects referring to single images
  * Scripting: Added API for editing tile layers using terrain sets (with a-morphous, #3758)
  * Scripting: Added file dialog API (with dogboydog, #3782)
  * Scripting: Support erasing tiles in Tool.preview and TileMap.merge
  * Scripting: Added Geometry interface with line and ellipse helpers
  * Scripting: Added WangSet.effectiveTypeForColor
  * Fixed crash when changing file property of custom class (#3783)
  * Fixed loading of invalid color properties (#3793)
  * Fixed handling of enum values with 31 flags and fixed the applied limit (#3658)
  * Fixed object preview position with parallax factor on group layer (#3669)
  * Fixed hover highlight rendering with active parallax factor (#3669)
  * Fixed updating of object selection outlines when changing parallax factor (#3669)
  * Fixed "Offset Map" action to offset all objects when choosing "Whole Map" as bounds
  * Fixed several issues with drawing ellipses (#3776)
  * Fixed Terrain Fill Mode for sets containing transitions to empty (#3774)
  * Godot 4 plugin: Export custom tile properties as Custom Data Layers (with Kevin Harrison, #3653)
  * AppImage: Updated to Sentry 0.6.5
  * Qt 6: Increased the image allocation limit from 1 GB to 4 GB (#3616)
* Tue Apr  4 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.10.1:
  * Make panning with Space require pressing a mouse button as well (#3626)
  * Scripting: Added read-only access to Project properties (by dogboydog, #3622)
  * Scripting: Fixed behavior of Dialog.SameWidgetRows (#3607)
  * Fixed object labels to adjust to application font changes
  * Fixed grid rendering for odd Hex Side Length values (#3623)
  * Fixed tile stamp getting messed up on staggered maps in some cases (#3431)
  * JSON plugin: Fixed loading of empty tilesets created by script (#3542)
  * Godot 4 plugin: Removed depth limit for .godot project file (#3612)
  * Improved Terrain Brush for Hexagonal (Staggered) maps with side length 0 (#3617)
  * Removed "Add Folder to Project" button from the startup page
  * Qt 6: Increased the image allocation limit from 128 MB to 1 GB (#3616)
  * Qt 6 / Linux: Fixed long startup time for some icon themes
  * snap: Updated from core20 to core22 (now uses Qt 5.15)
  * Qbs: Added projects.Tiled.libDir option (#3613)
- Remove tiled-1.10.0-lib.patch
* Wed Mar 29 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Bump qbs setup-toolchains call to gcc++-13 now that we are using
  gcc13 as default compiler. Fixes build in Tumbleweed.
* Wed Mar 15 2023 Michael Vetter <mvetter@suse.com>
- Add tiled-1.10.0-lib.patch:
  Move so files into corresponding directories
* Sat Mar 11 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.10.0:
  * Restored Tiled 1.8 file format compatibility by default (#3560)
  * Added action search popup on Ctrl+Shift+P (with dogboydog, #3449)
  * Added Godot 4 export plugin (by Rick Yorgason, #3550)
  * Added file system actions also for tileset image based tilesets (#3448)
  * Added custom class option to disable drawing fill for objects (with dogboydog, #3312)
  * Added option to choose a custom interface font (#3589)
  * Implemented rendering of major grid lines for staggered / hexagonal maps (#3583)
  * Fixed new layer names to be always unique (by Logan Higinbotham, #3452)
  * Fixed broken tile images after importing/exporting a tileset
  * AutoMapping: Added support for output set probability (#3179)
  * AutoMapping: When input regions are defined, match in order by default (#3559)
  * AutoMapping: Skip locked layers when applying rules (#3544)
  * AutoMapping: Fixed NoOverlappingOutput in case of multiple output indices (#3551)
  * AutoMapping: Fixed automatic output regions for object output (#3473)
  * AutoMapping: Fixed crash on undo when output layers have properties
  * Scripting: Added Object.setColorProperty and Object.setFloatProperty (#3423)
  * Scripting: Added tiled.projectFilePath
  * Scripting: Added tiled.versionLessThan
  * Scripting: Added TileMap.toImage (#3519)
  * Scripting: Added Tool.targetLayerType (#3248)
  * Scripting: Added region.contiguousRegions() (#3576)
  * Scripting: Added tiled.compress and tiled.decompress (#3153)
  * Scripting: Added Base64 encoding and decoding API (#3153)
  * Scripting: Allow assigning null to Tile.objectGroup (by Logan Higinbotham, #3495)
  * Scripting: Allow changing the items in a combo box added to a dialog
  * Scripting: Fixed painting issues after changing TileLayer size (#3481)
  * Scripting: Renamed Tileset.collection to Tileset.isCollection (#3543)
  * Defold plugin: Allow overriding z value also when exporting to .collection (#3214)
  * Qt 6: Fixed invisible tileset tabs when only a single tileset is open
  * Qt 6: Fixed behavior of "Class of" selection popup
  * Qt 6: Fixed tile rendering when OpenGL is enabled (#3578)
  * Fixed positioning of point object name labels (by Logan Higinbotham, #3400)
  * Fixed slight drift when zooming the map view in/out
  * Fixed remaining lag after switching off hardware acceleration (#3584)
  * Fixed point object hover highlight position (#3571)
  * Fixed drawing lines with stamps having differently sized variations (#3533)
  * Fixed compile against Qt 6.4
  * snap: Added Wayland platform plugin and additional image format plugins
  * AppImage: Updated to Sentry 0.6.0
  * Updated Bulgarian, French, German, Hungarian, Russian and Swedish translations
* Sun Sep 18 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.9.2:
  * Allow adding maps to image collection tilesets (#3447)
  * Auto-detect JSON file format when importing custom types (#3472)
  * Added file system actions to the tile context menu (#3448)
  * Fixed possible crash in Custom Types Editor (#3465)
  * Fixed display of overridden values from a nested class
  * Fixed ability to reset nested string and file properties (#3409)
  * Fixed changing nested property values for multiple objects (#3344)
  * Fixed resolving of class properties on export to affect all data types (#3470)
  * Fixed possible duplication of Automapping Rules Tileset (#3462)
  * Fixed case where object labels could become visible for hidden layer (#3442)
  * Fixed updating of custom property colors when changing style
  * Scripting: Added Tileset.findTile
  * AutoMapping: Fixed applying of rule probability (#3425)
  * Defold plugin: Assign incrementing z values and allow specifying tile_set (#3214)
  * Updates to German translation
* Fri Aug 12 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.9.1:
  * Fixed properties-related crash when having no project loaded
  * Fixed loading of custom tile image rectangles (#3405)
  * Fixed loading of member values for nested classes (#3414)
  * Fixed visibility of "Move Object to Layer" sub-menu (#3417)
  * Fixed shadow offset for other maps in a world (#3429)
  * Fixed class dropdown to update immediately when changing custom types (#3398)
  * Fixed deleting an overridden property to not make it disappear (#3409)
  * Scripting: Added TilesetsView.currentTilesetChanged
  * JSON plugin: Fixed loading image layer "repeatx/y" properties #3428)
  * snap: Fixed startup error due to missing libQt5Concurrent.so.5 (#3408)
  * AppImage: Use custom AppRun that can call all binaries (#3415)
  * AppImage: Updated to Sentry 0.5.0
  * Updated Chinese (Simplified) and Portuguese translations
* Sat Jun 25 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.9.0:
  * Added option to ignore transparent pixels when selecting tile objects (#1477)
  * Added support for sub-images in image collection tilesets (#1008)
  * Added "Class" field to all data types, referring to a custom class
  * Added Tile Render Size and Fill Mode options to Tileset
  * Added %%worldfile variable for custom commands (by Pixel-Nori, #3352)
  * Added 'New Project' action, replacing 'Save Project As' (#3279)
  * Added ability to load .tiled-session files from command-line
  * Merged Object Types with Property Types
  * Don't scale point objects with the zoom level (#3356)
  * Take into account image layer content when determining visual map size (#3386)
  * Scripting: Added Dialog API for building custom UI (by tileboydog, #3384)
  * Scripting: Added -e,--evaluate to run a script from command-line
  * Scripting: Added Tool.toolBarActions property (#3318)
  * Scripting: Added Tileset.columnCount property
  * Scripting: Added ImageLayer.image property
  * Scripting: Added access to selected terrain in tileset editor
  * AutoMapping: Applying rules is now 10-30x faster
  * AutoMapping: Explicit "regions" layers are no longer needed and have been deprecated (#1918)
  * AutoMapping: "AutoMap While Drawing" no longer creates separate undo steps (#2166)
  * AutoMapping: Custom tiles can now match "Empty", "Non-Empty" and "Other" tiles through a "MatchType" property (#3100)
  * AutoMapping: A custom tile with "MatchType" set to "Negate" can be used instead of "inputnot" layers
  * AutoMapping: Added built-in tileset with these custom rule tiles
  * AutoMapping: Added a number of per-rule options which can be set using rectangle objects
  * AutoMapping: Erase tiles by placing tiles with "MatchType" set to "Empty" on output layers (#3100)
  * AutoMapping: Accumulate touched layers in AutoMap While Drawing (#3313)
  * AutoMapping: Support map name filters in rules.txt (#3014)
  * AutoMapping: Show relevant custom properties when a rules map is detected
  * Optimized rendering of tinted layers by caching tinted images
  * tmxrasterizer: Added options to hide certain layer types (#3343)
  * Raised minimum supported Qt version from 5.6 to 5.12 (drops Windows XP support)
  * Raised minimum C++ version to C++17
  * Removed qmake project files (only Qbs supported now)
  * Python plugin: Now built against Python 3.8 on Windows and Linux
  * Updated Bulgarian, Czech, French and Russian translations
* Wed Jun 15 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.8.6:
  * Keep references between objects when copy/pasting or duplicating (#3361)
  * Improved default translation used in case of multiple options
  * Terrain Brush: Update preview on mouse release (#3381)
  * Fixed 'Add Variation' action in Tile Stamps context menu (#3362)
  * Fixed importing of removed shortcuts (#3367)
  * Fixed breaking of alternative shortcuts on import or reset (#3367)
  * Fixed conflict detection to handle alternative shortcuts (#3368)
  * Fixed locking up UI on property type name conflict (#3380)
  * Scripting: Fixed possible crash when accessing Layer.map
  * Defold plugins: Added support for rotated tiles (#3369)
  * Updates to German translation
* Tue May 24 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.8.5:
  * Made expanded group layers persistent (#3282)
  * Improved snapping behavior for scalable objects on staggered maps
  * Allow setting a shortcut on the 'Edit Tileset' action
  * Always select first entry while using the Open File in Project action
  * Improved Add Property dialog layout in case of long type names (#3302)
  * Fixed restoring of window layout when maximized (#590)
  * Fixed snapping when dragging templates into a map (#3326)
  * Fixed map selection rectangle in world for infinite maps (#3340)
  * Fixed 'Merge Layer Down' action for infinite maps
  * Fixed several small issues in the image color picker (#3348)
  * Fixed missing name for undo commands that add/remove maps from world
  * Fixed selection issues for tile objects with a non-zero tile offset
  * Fixed hover indicator sometimes overlapping selection indicator
  * Fixed removal of terrain info when removing tiles from a collection
  * Scripting: Fixed region.rects when compiled against Qt 5.9 to 5.13
  * Scripting: Layer.tintColor is now #ffffff when not set
  * Updated Chinese (Simplified) and Portuguese (Portugal) translations
* Fri Apr  1 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.8.4:
  * Fixed crash when trying to create an object
  * Fixed handling of deleted session file
* Fri Feb 18 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.8.2:
  * Fixed deactivating of tools when no layer is selected (avoids crash)
  * Fixed ability to reset custom 'color' and 'object' properties (#3270)
  * Fixed updating of layer positions when changing parallax factor of a group (#3175)
  * Scripting: Fixed crash when assigning null to the MapObject.tile property
  * Scripting: Fixed adding of tilesets when adding layers to a loaded map (#3268)
  * JSON format: Fixed layer locked status not getting saved (#2877)
* Fri Feb 18 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.8.1
  * Fixed pasted objects not getting selected if a tile layer was also copied
  * Fixed possible crash when trying to determine whether OpenGL is used
  * Fixed possible crash when using the Insert Tile tool
  * Fixed possible crash in tile stamp preview
  * AutoMapping: Fixed crash when an input layer does not exist (#3269)
  * Scripting: Automatically add tilesets to the map where needed (#3268)
  * snap: Updated from core18 to core20 (now uses Qt 5.12)
  * AppImage: Updated to Sentry 0.4.15
* Fri Feb 11 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.8.0:
  * Added support for custom enum properties (with svipal, #2941)
  * Added support for custom class properties (#489)
  * Added parallax origin property to the map (with krukai, #3209)
  * Added Repeat X/Y properties to Image Layers (with krukai, #3205)
  * Added an action for selecting all layers (Ctrl+Alt+A) (#3081)
  * Added actions to select or add tilesets to Project view context menu
  * Added cut/copy/paste actions to Tile Animation Editor
  * Improved undo behavior by merging sequential edits to the same property (#3103)
  * Improved multi-layer painting behavior (#3094)
  * Separated the X and Y components of the major grid option (#3208)
  * Added automatic fading out of the grid when zooming out a lot
  * AutoMapping: Made it find layers within groups (#1771)
  * AutoMapping: regions layer can now be used alongside region_input/output layers
  * AutoMapping: Recognize "//" layer name prefix for ignoring layers (#3262)
  * AutoMapping: Allow setting a rule map as project rules file (#3221)
  * Tweaked focus behavior in the Template Editor
  * Changed the default Terrain Brush shortcut back to T
  * Reset tile animations when disabling playback and when exporting as image
  * Don't require saving maps upon creation (#1902)
  * Apply transformation actions to the preview while placing tiles (#3091)
  * Allow using object context menu in object creation tools
  * Reduced the step size for the parallax factor property
  * Improved the logic for automatically switching tools (#2807)
  * Ignore selection changes when marking a file as modified (#3194)
  * Use the tileset background color in the collision editor (with Benja Appel, #3163)
  * Show the read error when using --export-map/tileset
  * Avoid deselecting all layers when clicking empty area in Layers view (#2806)
  * Scripting: Added File API
  * Scripting: Added support for loading JavaScript .mjs modules (#3261)
  * Scripting: Added tiled.applicationDirPath property
  * Scripting: Added tiled.extensionsPath property (#3139)
  * Scripting: Added missing Layer.tintColor property
  * Scripting: Added missing ObjectGroup.drawOrder property (#3147)
  * Scripting: Added TileMap.removeObjects (#3149)
  * Scripting: Added TileMap.regionEdited signal
  * Scripting: Added TileMap.layers and GroupLayer.layers properties, for convenience
  * Scripting: Added region.rects property and region.contains(x,y)
  * Scripting: Treat custom format extensions as case-insensitive (#3141)
  * Scripting: Allow tools to stay active when tiles or a terrain type are selected (#3201)
  * Scripting: Extended the terrain related API (#2663)
  * Scripting: tiled.activeAsset can be assigned asset created in script (#3160)
  * Scripting: Fixed possible crash after creating tilesets from script (#3229)
  * Scripting: Fixed possible crash in TileMap.autoMap
  * Scripting: Fixed tileset or tile references for maps loaded from script
  * Scripting: Avoid crash when script reload happens during popup (#2991)
  * Fixed the logic for handling group layer parallax factors (with LilithSilver, #3125)
  * Fixed keyboard modifiers getting stuck for Terrain Brush (#2678)
  * Fixed debug messages showing in the Console and Issues views
  * Fixed enabled state of File > Export action for tilesets (#3177)
  * Fixed Snap to Grid for hexagonal maps
  * Fixed AutoMapping rules file to update after changing project properties (#3176)
  * Fixed 'Detect Bounding Box' action missing in Keyboard settings
  * Fixed toggling "Clear View" on & off shifting the map
  * Fixed "Select object on map" when no object layer is selected (#3207)
  * Fixed adjusting of tile types when tileset width changed (by Albert Vaca Cintora, #3237)
  * Fixed missing Qt translations for Linux AppImage
  * Fixed minimap viewport position when layers are offset (#3211)
  * Fixed "Highlight Current Layer" getting confused (#3223)
  * Fixed Terrain Set type property to be disabled when appropriate (avoids crash)
  * Fixed saving broken references to files loaded using "ext:" prefix (#3185)
  * Fixed performance issue in Project view related to file icons
  * Fixed dynamic wrapping when adding tiles to a collection (#3076)
  * Fixed potential crash when changing a WangSet from script
  * Tiled Manual is now available in French
  * JSON plugin: Added "tmj", "tsj" and "tj" as accepted file extensions
  * YY plugin: Don't use safe writing of files
  * YY plugin: Write out custom "object" properties as instance name (instead of the ID)
  * YY plugin: Determine sprite names by looking for meta files (by krukai, #3213)
  * CSV plugin: Improved handling of infinite maps
  * RpMap plugin: Fixed hardcoded exported tile size (#3184)
  * libtiled-java: Introduced TilesetCache interface (by Samuel Manflame, #3117)
  * Updated to Sentry 0.4.14
  * Updated languages
* Mon Aug 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.7.2:
  * Avoid automatically replacing external tilesets with "similar" ones
  * Fixed copying and capturing stamps on staggered maps (#2874)
  * Fixed possible crash in Tile Animation Editor
  * Fixed data loss when saving maps with tilesets that failed to load (#3106)
  * Fixed creating multi-layer tile stamp from selection (#2899)
  * Scripting: Automatically reset object ID when adding to avoid duplicate IDs
  * Linux: Possible workaround for crash in clipboard manager
  * Updated to Sentry 0.4.12
  * Updated Italian translation
* Mon Jul 12 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.7.1:
  * Don't save export target and format to exported files
  * Fixed crashes resulting from the Tile Animation Editor
  * Fixed possible crash when pasting multi-layer stamp (#3097)
  * Fixed possible crash when restoring expanded layers in Objects view
  * Fixed parallax factor getting lost when layer is cloned (#3077)
  * Fixed an issue with synchronizing selected tiles to current stamp (#3095)
  * Commands: Fixed possible crash in Edit Commands window
  * Commands: Automatically quote the command executable
  * Commands: Improved starting directory for executable file chooser
  * Commands: Fixed the 'Clear' button to reset the shortcut
  * Updated to Sentry 0.4.11
  * Updated French translation
* Mon Jun  7 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.7.0:
  * Added basic "major grid" option with stronger lines (with Ilya Arkhanhelsky, #3032)
  * Added ability to rearrange tiles in a tileset (with José Miguel Sánchez García, #2983)
  * Added option to choose background fade color (with SchmidtWC, #3031)
  * Added portable mode, enabled when a "tiled.ini" is detected alongside the Tiled executable (#2945)
  * Disable project extensions by default, for security reasons (#3058)
  * Render selection preview and hovered item highlight above labels (#3036)
  * Changed the donation reminder to be non-modal
  * docs: Generate scripting API documentation using TypeDoc (with Erik Schilling (#2965) and MrMasterplan (#3040, #3041, #3045))
  * QMake/Qbs: Added a way to disable DBus support (with Dmitry Marakasov, #3039)
  * Scripting: Fixed 'mouseLeft' callback for scripted tools (#3050)
  * Scripting: Fixed loading of icons with explicit "ext:" prefix (#3048)
  * Scripting: Made TileMap coordinate conversion functions always work (#3054)
  * tBIN plugin: Convert 'color', 'object' and 'file' properties on save
  * Python plugin: Added Layer.offset and Layer.setOffset (with sverx, #3073)
  * Python plugin: Linux AppImage now supports Python 3.6 instead of 3.5
  * Fixed possible crash in Properties view when switching files
  * Fixed watching/unwatching of folders when adding/removing from project (#3035)
  * Fixed determining desired file format by extension on export
  * Fixed compilation issue with GCC 10 (#3037)
  * Updated Bulgarian, Portuguese (Portugal), Russian and Turkish translations
- Remove tiled-endl.patch: upstreamed
* Wed Apr 28 2021 Michael Vetter <mvetter@suse.com>
- Update tiled-endl.patch:
  Update from commit 7059846dc551a5d6b3cda8c78aa990aff8a4861f
  to final one 068d0bf2e9632bf7473b40e4073eb3787f8889d1 since it
  works with more Qt versions
* Mon Apr 26 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.6.0:
  * Added object selection preview
  * Added toggle to select enclosed rather than touched objects (#3023)
  * Added Sentry crash handler to Linux AppImage (disabled by default)
  * Added %%tileid variable for custom commands on tilesets (#3026)
  * Added option to lock the position of views and tool bars
  * Added toggle to show/hide other maps in the same world (#2859)
  * Added a helpful text to Terrain Sets view when it is empty (#3015)
  * Allow opening projects from the File menu (#3000)
  * Made the terrains list in the Terrain Sets view not collapsible (#3015)
  * Automatically select the first terrain when selecting a Terrain Set (#3015)
  * When duplicating objects, place the duplicates next to the originals (#2998)
  * Tweaked selection outlines to be a little fatter and adjust to DPI
  * Write --export-formats output to stdout instead of stderr (#3002)
  * Allow hiding objects in the Tile Collision Editor
  * Scripting: Added missing Tileset.transparentColor property
  * Fixed 'Detach templates' export option to add tilesets when needed
  * Fixed Terrain Brush behavior on map edges
  * Fixed Terrain Brush behavior for sets transitioning to nothing
  * Fixed loss of edit focus when hovering tileset while assigning terrain (#3015)
  * Fixed shortcuts for flipping or rotating the current terrain pattern
  * Fixed switching to Terrain Brush when clicked terrain is already selected (#3015)
  * Fixed state of "dynamic wrapping" toggle button on startup
  * Fixed parallax layer positioning when reordering layers (#3009)
  * snap: Added 'removable-media' plug, for accessing USB drives
  * snap: "Open Containing Folder" action now also selects the file
  * JSON plugin: Write out "version" property as string (#3033)
  * YY plugin: Fixed plugin loading issue for qmake builds
  * libtiled-java: Optimized for multithreaded usage (by Samuel Manflame, #3004)
  * Updated Bulgarian, French, Portuguese (Portugal), Swedish and Turkish translations
  * Added Thai translation (by Thanachart Monpassorn, currently at 54%%)
- Add tiled-endl.patch: See https://github.com/mapeditor/tiled/issues/3037
* Mon Mar 29 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.5.0:
  * Unified Wang and Terrain tools (backwards incompatible change!)
  * Added support for a per-layer parallax scrolling factor (#2951)
  * Added export to GameMaker Studio 2.3 (#1642[2])
  * Added option to change object selection behavior (#2865[3])
  * Added Monospace option to the multi-line text editor
  * Added option to auto-scroll on middle click
  * Added smooth scrolling option for arrow keys
  * Added a 'Convert to Polygon' action for rectangle objects
  * Added support for drawing with a blob tileset
  * Added 'Duplicate Terrain Set' action
  * Added Terrain Set type (Corner, Edge or Mixed)
  * Added support for rotating and flipping Terrain tiles (by Christof Petig, #2912[4])
  * Added support for exporting to RPTools MapTool[5] RpMap files (by Christof Petig, #2926[6])
  * Added Ctrl+Shift to toggle Snap to Fine Grid (by sverx, #2895[7])
  * Eraser: Added Shift to erase on all layers (by Michael Aganier, #2897[8])
  * Automatically add .world extension to new World files
  * Shape Fill Tool now displays the size of the current shape (#2808[9])
  * Tile Collision Editor: Added action to add an auto-detected bounding box collision rectangle (by Robin Macharg, #1960[10])
  * Tile Collision Editor: Added context menu action to copy selected collision objects to all other selected tiles (by Robin Macharg, #1960[10])
  * Tilesets view: Added "Edit Tileset" action to tab context menu
  * Tilesets view: Added "Add External Tileset" action to tilesets menu
  * Scripting: Added initial API for creating and modifying Terrain Sets
  * Scripting: Added API for working with images (#2787[11])
  * Scripting: Added API for launching other processes (#2783[12])
  * Scripting: Added MapView.center property
  * Scripting: Added missing Layer.id and Layer.parentLayer properties
  * Scripting: Enable extending most context menus
  * Scripting: Fixed reset of file formats on script reload (#2911[13])
  * Scripting: Fixed missing GroupLayer and ImageLayer constructors
  * Scripting: Added default icon for scripted actions
  * Enabled high-DPI scaling on Linux and changed rounding policy
  * Remember last file dialog locations in the session instead of globally
  * Fixed loading extension path from project config (by Peter Ruibal, #2956[14])
  * Fixed performance issues when using a lot of custom properties
  * Fixed storing template instance size when overriding the tile (#2889[15])
  * Fixed removal of object reference arrow when deleting target object (#2944[16])
  * Fixed updating of object references when layer visibility changes
  * Fixed map positioning issues in the World Tool (#2970[17])
  * Fixed handling of Shift modifiers in Bucket and Shape Fill tools (#2883[18])
  * Fixed scrolling speed in Tileset view when holding Ctrl
  * Fixed issue causing export.target to get written out as "."
  * Fixed "Repeat last export on save" when using Save All (#2969[19])
  * Fixed interaction shape for rectangle objects to be more precise (#2999[20])
  * Fixed "AutoMap While Drawing" not applying when using Cut/Delete
  * Fixed path in AutoMap error message when rules file doesn't exist
  * Lua plugin: Don't embed external tilesets, unless enabled as export option (#2120[21])
  * Python plugin: Added missing values to MapObject.Shape enum (#2898[22])
  * Python plugin: Fixed linking issue when compiling against Python 3.8
  * CSV plugin: Include flipping flags in exported tile IDs
  * GMX plugin: Take tile object alignment into account
  * Linux: "Open Containing Folder" action now also selects the file
  * libtiled-java: Many updates (by Henri Viitanen, #2207[23])
  * Ported Tiled to Qt 6 (releases still use 5.15 for now)
* Tue Nov 17 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4.3:
  * Improved error message when adding external tileset
  * Tile Collision Editor: Fixed invisible tile for isometric
    oriented tileset (#2892)
  * Fixed Object Alignment not getting set when reloading a tileset
  * Ignore attempts to replace a tileset with itself
  * qmake: Support linking to system Zstd on all UNIX-like systems
* Thu Aug  6 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4.2:
  * Reverted the default layer data format back to CSV
    (was changed to Zstd by accident in 1.4.0)
  * Added ability to draw lines using click+drag
    (in addition to click and click) when holding Shift
  * Improved positioning when adding maps to world via context menu
  * Disable instead of hide the "Save As Template" action when using embedded tilesets
  * Made Ctrl turn off snapping if Snap to Fine Grid is enabled (#2061)
  * Set minimum value of tile width and height to 1
  * Fixed Select Same Tile tool behavior for empty tiles
  * Fixed clickability of the dot in point objects
  * Fixed adjusting of terrain images when tileset width changes
  * Worlds: Fixed potential data loss when opening .world file
  * tmxrasterizer: Added --show-layer option (by Matthias Varnholt, #2858)
  * tmxrasterizer: Added parameter to advance animations (by Sean Ballew, #2868)
  * Scripting: Initialize tile layer size to map size upon add (#2879)
  * Windows installer: Made creation of the desktop shortcut optional
  * Windows installer: Made the launching of Tiled optional
  * Updated Qt to 5.12.9 on all platforms except Windows XP and snap releases
  * snap: Fixed issues with storing the default session (#2852)
  * snap: Enabled support for Zstandard (#2850)
* Fri Jun 26 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4.1:
  * When opening a .world file, load the world and open its first map
  * When opening an object template, show it in the Template Editor
  * Fixed crash on trying to export using the command-line (#2842[1])
  * Fixed crash when deleting multiple objects with manual drawing order (#2844[2])
  * Fixed potential crash when removing a tileset
  * Fixed potential scaling happening for maps used as tilesets (#2843[3])
  * Fixed positioning of map view when switching between maps in a world
  * Fixed file dialog start location
  * Scripting: Fixed issues with absolute file paths on Windows (#2841[4])
  * Lua plugin: Fixed syntax used for object properties (#2839[5])
* Thu Jun 18 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4.0:
  * Added support for projects (#1665[1])
  * Added object reference property type (with Steve Le Roy Harris and
  Phlosioneer, #707[2])
  * Added world editing tool for adding/removing and moving around maps in a
  world (with Nils Kübler, #2208[3])
  * Added a quick "Open file in Project" (Ctrl+P) action
  * Added new Object Alignment property to Tileset (with Phlosioneer, #91[4])
  * Added layer tint color (by Gnumaru, #2687[5])
  * Added support for using maps as images (with Phlosioneer, #2708[6])
  * Added 'Open with System Editor' action for custom file properties
  (#2172[7])
  * Added option to render object names when exporting as image (#2216[8])
  * Added 'Replace Tileset' action to Tilesets view
  * Added shortcut to tooltips for all registered actions
  * Added automatic reloading of object templates (by Phlosioneer, #2699[9])
  * Added 'Clear Console' button and context menu action (#2220[10])
  * Added 'Reopen Closed File' (Ctrl+Shift+T) action
  * Added status bar button to toggle the Console view
  * Added a border around the tile selection highlight
  * Switch current tileset tab if all selected tiles are from the same
  tileset (by Mitch Curtis, #2792[11])
  * Made tileset dynamic wrapping toggle persistent
  * Properties view: Added action for adding a property to context menu
  (#2796[12])
  * Optimized loading of CSV tile layer data (by Phlosioneer, #2701[13])
  * Improved map positioning when toggling 'Clear View'
  * Remember the preferred format used for saving
  * Normalize rotation values when rotating objects (#2775[14])
  * Removed the Maps view (replaced by Project view)
  * Removed file system hierarchy from Templates view (replaced by Project
  view)
  * Fixed potential crash when triggering AutoMap (#2766[15])
  * Fixed the status bar placement to be always at the bottom of the window
  * Fixed potential issue with automatic reloading of files (#1904[16])
  * Fixed issue where image layer images cannot be loaded from Qt resource
  files (by obeezzy, #2711[17])
  * GmxPlugin: Added support for layer tint color
  * Scripting: Assign global variables to console script evaluations (by
  Phlosioneer, #2724[18])
  * Scripting: Added coordinate conversion to TileMap
  * Scripting: Added support for custom "file" properties
  * Scripting: Added checks for nullptr arguments (by Phlosioneer, #2736[19])
  * Scripting: Added some missing tileset related properties
  * Scripting: Added FileInfo API with various file path operations (with
  David Konsumer, #2822[20])
  * Scripting: Provide access to registered file formats (by Phlosioneer,
  [#2716][21])
  * Scripting: Enabled scripted formats to be used on the command-line
  * Scripting: Added functions to access inherited properties (by Bill Clark,
  [#2813][22])
  * Scripting: Introduced __filename global value (with konsumer)
  * Scripting: Fixed ObjectGroup.insertObjectAt to use the index
  * docs: Clarify "can contain" documentation and error handling (by
  Phlosioneer, #2702[23])
  * docs: Document all optional attributes, update some docs (by Phlosioneer,
  [#2705][24])
  * docs: Alphabetize scripting API reference (by Phlosioneer, #2720[25])
  * docs: Added missing BinaryFile constructor docs (by Phlosioneer,
  [#2732][26])
  * docs: Enabled Algolia powered search
  * Updated Bulgarian, Chinese (Simplified), Czech, Finnish, French,
  Norwegian Bokmål, Portuguese (Portugal) and Turkish translations
* Wed May 27 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.3.5:
  * Fixed initialization and restoring of map view (#2779)
  * Fixed skewed tile terrain/Wang overlays for non-square tiles (#1943)
  * Fixed link color on dark theme
  * Fixed small issue when right-clicking embedded tileset tab
  * Fixed Wang Sets toggle to also appear in the Tileset menu
  * Scripting: Fixed issue when closing/committing BinaryFile (#2801)
  * Scripting: Fixed "Safe writing of files" when writing with TextFile
  * Updated Qt to 5.12.8 on all platforms
  * Small translation updates to Bulgarian, French and Portuguese
* Wed Apr 15 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.3.4:
  * Fixed automatic reload issues when editing object types (regression in 1.3.1,
  [#2768])
  * Scripting: Added methods to get tileset's image size (backported from 1.4, #2733)
  * Scripting: Fixed map.tilesets when 'Embed tilesets' is enabled
  * Fixed the "Fix Tileset" button in the Template Editor
* Wed Mar  4 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.3.3:
  * Fixed loading of compression level (#2753)
  * Fixed default value for Hex Side Length property
  * Fixed hiding of status bar text for some tools
  * Fixed removing of object labels when removing a group layer
  * GmxPlugin: Fixed compatibility with GameMaker 1.4.9999
  * Scripting: Made TextFile.commit and BinaryFile.commit close as well
  * Scripting: Fixed crashes when modifying certain new objects (#2747)
  * Scripting: Fixed potential crash in Asset.macro/undo/redo/isModified
  * Scripting: Fixed potential crash when accessing Tool.preview
  * Scripting: Fixed loading of images from extensions folder
  * Scripting: Reload extensions also when files are added/removed
  * Updated Bulgarian translation
* Wed Jan 22 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.3.2:
  * Fixed initialization of selected layers (#2719)
  * Fixed stamp action shortcuts not being configurable (#2684)
  * Fixed the tileset view to respect the 'wheel zooms by default' preference
  * Fixed insertion position when using drag-n-drop to rearrange layers
  * Fixed displayed layer data format in Properties
  * Fixed repeating of export when map is saved by a custom command (#2709)
  * Fixed issue when multiple worlds are loaded that use pattern matching
  * Issues view can now be hidden by clicking the status bar counters
  * macOS: Fixed black toolbar when enabling OpenGL rendering (#1839)
  * Windows: Fixed context menus activating first item on release (#2693)
  * Windows installer: Include the 'defoldcollection' plugin (#2677)
  * libtiled: Avoid inheriting Properties from QVariantMap (#2679)
  * docs: Added some notes to Python and JavaScript pages (#2725)
  * Updated Qt from 5.12.5 to 5.12.6
  * Updated Finnish translation (by Tuomas Lähteenmäki and odamite)
  * Updated part of Italian translation (by Katia Piazza)
* Wed Nov 20 2019 Michael Vetter <mvetter@suse.com>
- Update to 1.3.1:
  * Added reloading of object types when changed externally (by Jacob Coughenour, #2674)
  * Added a status bar to the startup screen
  * Made the shortcuts for the tools configurable (#2666)
  * Made Undo/Redo shortcuts configurable (#2669)
  * Fixed importing of keyboard settings (.kms files) (#2671)
  * Fixed small window showing up on startup for a split second
  * Windows: Fixed the shipped version of OpenSSL (fixes new version notification)
  * Tiled Quick: Don't compile/install by default (#2673)
- Remove tiled-1.3.0-disable-quick.patch: upstreamed
* Thu Nov 14 2019 Michael Vetter <mvetter@suse.com>
- Update to 1.3.0:
  * Added support for extending Tiled with JavaScript (#949)
  * Added error and warning counts to the status bar
  * Added Issues view where you can see warnings and errors and interact with them
  * Added configuration of keyboard shortcuts (#215)
  * Added status bar notification on new releases (replacing Sparkle and WinSparkle)
  * Added option to show tile collision shapes on the map (#799)
  * Added switching current layer with Ctrl + Right Click in map view
  * Added search filter to the Objects view (#1467)
  * Added icons to objects in the Objects view
  * Added dynamic wrapping mode to the tileset view (#1241)
  * Added a *.world file filter when opening a world file
  * Added support for .world files in tmxrasterizer (by Samuel Magnan, #2067)
  * Added synchronization of selected layers and tileset when switching between maps in a world (by JustinZhengBC, #2087)
  * Added actions to show/hide and lock/unlock the selected layers
  * Added toggle button for "Highlight Current Layer" action
  * Added custom output chunk size option to map properties (by Markus, #2130)
  * Added support for Zstandard compression and configurable compression level (with BRULE Herman and Michael de Lang, #1888)
  * Added option to minimize output on export (#944)
  * Added export to Defold .collection files (by CodeSpartan, #2084)
  * Added a warning when custom file properties point to non-existing files (#2080)
  * Added shortcuts for next/previous tileset (#1238)
  * Added saving of the last export target and format in the map/tileset file (#1610)
  * Added option to repeat the last export on save (#1610)
  * Added Fit Map in View action (by Mateo de Mayo, #2206)
  * Tile Collision Editor: Added objects list view
  * Changed the Type property from a text box to an editable combo box (#823)
  * Changed animation preview to follow zoom factor for tiles (by Ruslan Gainutdinov, #2050)
  * Changed the shortcut for AutoMap from A to Ctrl+M
  * AutoMapping: Added "OverflowBorder" and "WrapBorder" options (by João Baptista de Paula e Silva, #2141)
  * AutoMapping: Allow any supported map format to be used for rule maps
  * Python plugin: Added support for loading external tileset files (by Ruin0x11, #2085)
  * Python plugin: Added Tile.type() and MapObject.effectiveType() (by Ruin0x11, #2124)
  * Python plugin: Added Object.propertyType() (by Ruin0x11, #2125)
  * Python plugin: Added Tileset.sharedPointer() function (#2191)
  * tmxrasterizer: Load plugins to support additional map formats (by Nathan Tolbert, #2152)
  * tmxrasterizer: Added rendering of object layers (by oncer, #2187)
  * Fixed missing native styles when compiled against Qt 5.10 or later (#1977)
  * Fixed file change notifications no longer triggering when file was replaced (by Nathan Tolbert, #2158)
  * Fixed layer IDs getting re-assigned when resizing the map (#2160)
  * Fixed performance issues when switching to a new map in a world with many maps (by Simon Parzer, #2159)
  * Fixed restoring of expanded group layers in Objects view
  * Fixed tileset view to keep position at mouse stable when zooming (#2039)
  * libtiled-java: Added support for image layers and flipped tiles (by Sergey Savchuk, #2006)
  * libtiled-java: Optimized map reader and fixed path separator issues (by Pavel Bondoronok, #2006)
  * Updated builds on all platforms to Qt 5.12 (except snap release)
  * Raised minimum supported Qt version from 5.5 to 5.6
  * Raised minimum supported macOS version from 10.7 to 10.12
  * Removed option to include a DTD in the saved files
  * Removed the automappingconverter tool
  * snap: Updated from Ubuntu 16.04 to 18.04 (core18, Qt 5.9)
  * Updated Chinese, Portuguese (Portugal), Turkish and Ukrainian translations
- Add tiled-1.3.0-disable-quick.patch:
  Disable build tiledquick and tiledquickplugin as they are not useful yet.
  And they cause trouble because they get installed to the wrong location.
  They will be disabled upstream in 1.3.1 too.
* Wed May 22 2019 mvetter@suse.com
- Update to 1.2.4:
  * Fixed view boundaries to take into account layer offsets
  * Fixed map size when switching infinite off
  * Fixed the image cache to check file modification time
  * Fixed updating a few things when changing tileset drawing offset
  * Fixed position of tile object outline on isometric maps
  * Fixed saving of tile stamps when using the Shape Fill Tool
  * tBIN plugin: Fixed loading of some tilesets on Linux
  * tBIN plugin: Fixed possible crash when images can't be found
  * Python plugin: Disable this plugin by default, to avoid crashes on startup
  * JSON plugin: Fixed writing of position for objects without ID
  * Added Swedish translation
  Changelog from 1.2.3:
  * Fixed cut/copy in Tile Collision Editor
  * Fixed crash when trying to add Wang colors without a selected Wang set
  * tBIN plugin: Fixed hang when locating missing tileset image
  * CSV plugin: Fixed exporting of grouped tile layers
* Thu Jan 24 2019 mvetter@suse.com
- Update to 1.2.2:
  * Added 'json1' plugin that exports to the old JSON format (#2058)
  * Enable the adding of point objects in Tile Collision Editor (#2043)
  * Reload AutoMapping rules when they have changed on disk (by Justin Zheng, #1997)
  * Fixed remembering of last used export filter
  * Fixed label color to update when object layer color is changed (by Justin Zheng, #1976)
  * Fixed stamp and fill tools to adjust when tile probability is changed (by Justin Zheng, #1996)
  * Fixed misbehavior when trying to open non-existing files
  * Fixed mini-map bounds when layer offsets are used in combination with group layers
  * Fixed Templates view missing from the Views menu (#2054)
  * Fixed Copy Path / Open Folder actions for embedded tilesets (#2059)
  * Python plugin: Made the API more complete (#1867)
  * Updated Chinese, German, Korean, Norwegian Bokmål, Portuguese (Portugal) and Ukrainian translations
* Mon Nov 19 2018 mvetter@suse.com
- Update to 1.2.1:
  * Fixed JSON templates not being visible in Templates view (#2009[1])
  * Fixed Maps view to show all readable map formats
  * Fixed crash when deleting a command using the context menu (by Robert Lewicki, #2014[2])
  * Fixed crash after a world file failed to load
  * Fixed Select None action to be enabled when there is any selection
  * Fixed disappearing of tile types on export/import of a tileset (#2023[3])
  * Fixed tool shortcuts when using Spanish translation
  * Fixed saving of the "Justify" alignment option for text objects (#2026[4])
  * Changed Cut, Copy and Delete actions to apply based on selected layer types
  * Updated Russian translation (by Rafael Osipov, #2017[5
* Mon Sep 24 2018 mvetter@suse.com
- Update to 1.2.0:
  * Added multi-layer selection, including multi-layer tile layer editing
  * Added support for multi-map worlds (#1669[1])
  * Added ability to extend existing polylines (with Ketan Gupta, #1683[2])
  * Added option to highlight the hovered object (#1190[3])
  * Added news from website to the status bar (#1898[4])
  * Added option to show object labels for hovered objects
  * Added option to embed tilesets on export (#1850[5])
  * Added option to detach templates on export (#1850[5])
  * Added option to resolve object types and properties on export (#1850[5])
  * Added Escape for switching to the Select Objects tool and for clearing the selection
  * Added Escape to cancel the current action in all object layer tools
  * Added double-click on polygon objects to switch to Edit Polygons tool
  * Added interaction with segments for polygons, for selection and dragging
  * Added double-clicking a polygon segment for inserting a new point at that location
  * Added action to lock/unlock all other layers (by kralle333, #1883[6])
  * Added --export-tileset command line argument (by Josh Bramlett, #1872[7])
  * Added unique persistent layer IDs (#1892[8])
  * Added 'version' and 'tiledversion' to external tileset files
  * Added full paths to Recent Files menu as tool tips (by Gauthier Billot, #1992[9])
  * Create Object Tools: Show preview already on hover (#537[10])
  * Objects view: Only center view on object on press or activation
  * Objects view: When clicking a layer, make it the current one (by kralle333, #1931[11])
  * Unified the Create Polygon and Create Polyline tools
  * JSON plugin: Made the JSON format easier to parse (by saeedakhter, #1868[12])
  * Tile Collision Editor: Allowed using object templates
  * Templates view: Don't allow hiding the template object
  * Python plugin: Updated to Python 3 (by Samuli Tuomola)
  * Python plugin: Fixed startup messages not appearing in debug console
  * Python plugin: Fixed file change watching for main script files
  * Lua plugin: Include properties from templates (#1901[13])
  * Lua plugin: Include tileset column count in export (by Matt Drollette, #1969[14])
  * tBIN plugin: Don't ignore objects that aren't perfectly aligned (#1985[15])
  * tBIN plugin: Fixed "Unsupported property type" error for newly added float properties
  * Automapping: Report error when no output layers are found
  * AutoMapping: Changed matching outside of map boundaries and added 'MatchOutsideMap' option
  * Linux: Modernized the appstream file (by Patrick Griffis)
  * libtiled: Allow qrc-based tileset images (#1947[16])
  * libtiled-java: Fixed loading maps with multiple external tilesets
  * Optimized deletion of many objects (#1972[17])
  * Make Ctrl+Q work for quitting also on Windows (#1998[18])
  * Fixed randomizing of terrain, Wang tiles and stamp variations (#1949[19])
  * Fixed tilesets getting added to maps when they shouldn't be (#2002[20])
  * Fixed issue with default font size in combination with custom family (#1994[21])
  * Fixed the tile grid to render below labels, handles and selection indicators
  * Fixed confirming overwrite when exporting a tileset
  * Fixed reading of infinite maps that don't use chunked layer data
  * Updated Bulgarian, Dutch, French, German, Norwegian Bokmål, Portuguese (Portugal) and Turkish translations
- Install appdata file in right location and use tiled packaged instead of tmxtools
* Tue Jul 17 2018 mvetter@suse.com
- Update to 1.1.6:
  * Fixed Terrain Brush issue on staggered isometric maps (#1951)
  * Fixed objects to stay selected when moving them between layers
  * Fixed small tab bar rendering issue on high DPI displays
  * Fixed rendering of arrows on scroll bar buttons
  * Fixed object labels to adjust properly to the font DPI
  * Fixed resize handle locations for multiple zero-sized objects
  * Fixed handling of arrow keys on focused layer combo box (#1973)
  * Tile Collision Editor: Fixed handling of tile offset (#1955)
  * Tile Collision Editor: Fixed potential crash on Undo (#1965)
  * Python plugin: Added some missing API to the Cell class
  * Updates to German, Hungarian, Norwegian Bokmål, Polish, Portuguese (Portugal), Russian and Ukrainian translations
* Thu Apr 26 2018 mvetter@suse.com
- Update to 1.1.5:
  * Fixed erasing mode of the Terrain Brush
  * Fixed crash after editing a template
  * Fixed rendering of eye/lock icons in Layers view
  * Fixed object index when undoing Move Object to Layer action (#1932[1])
  * Fixed shortcuts for flipping and rotating objects (#1926[2])
  * Fixed dynamic retranslation of tools and tool actions
  * Fixed possible crash when undoing/redoing Wang color changes
  * Fixed handling of sub-properties in Object Type Editor (#1936[3])
  * Fixed crash when deleting an object right before dragging it (#1933[4])
  * Adjust Wang tile data when tileset column count changes (#1851[5])
  * Improved fill behavior in case of selection on infinite map (#1921[6])
  * Removed ability to hide tile collision objects (#1929[7])
  * Remove tile collision layer along with the last object (#1230[8])
  * JSON plugin: Made the reader more strict about object types (#1922[9])
  * JSON plugin: Added support for Wang sets
* Wed Mar 28 2018 mvetter@suse.com
- Update to 1.1.4:
  * Fixed exporting of external tilesets to JSON or TSX formats
  * Fixed problem with embedding or exporting tilesets with Wang sets
  * Fixed tiles placed by the terrain tool being considered different (#1913[1])
  * Fixed text alignment values appearing at random in Properties view (#1767[2])
  * Re-enabled Space for toggling layer visibility
  * Migrate properties set on tile collision layer to the tile (#1912[3])
  * Don't reset stamp brush state when pressing Alt
  * Automapping: Apply rules to selected area when there is one
  * Windows and Linux: Updated builds to Qt 5.10.1
  * Linux: Indicate Tiled can open multiple files at once in desktop file
  * Lowered the minimum supported version of Qt to 5.5
* Wed Mar  7 2018 mvetter@suse.com
- Update to 1.1.3:
  * Fixed crash when removing a tileset referenced by multiple objects
  * Fixed crash on paste when it introduced more than one new tileset
  * Fixed Invert Selection for non-infinite maps
  * Fixed Select All to not select objects on locked layers
  * Fixed logic determining the tilesets used by a tile layer
  * Fixed copy/paste changing object order (#1896[1])
  * Fixed tileset getting loaded twice when used by the map and a template
  * Fixed repainting issues on undo/redo for new maps (#1887[2])
  * JSON plugin: Fixed loading of infinite maps using CSV tile layer format (#1878[3])
  * Updated Hungarian, Japanese, Norwegian Bokmål, Portuguese and Ukrainian translations
* Wed Jan 31 2018 mvetter@suse.com
- Update to 1.1.2:
  * Fixed possible crash while editing polygons
  * Fixed hang when loading map file with empty compressed layer data
  * Fixed selection of tile stamp to work on mouse click
  * Fixed tools not being up to date on modifier keys after activation
  * Fixed "Offset Map" action for infinite maps (#1866)
  * Templates view: Keep template centered when resizing view
  * Tile Collision Editor: Keep tile centered when resizing view
  * Tile Collision Editor: Display tool info text in status bar
  * JSON plugin: Fixed reading of infinite maps (#1858)
  * libtiled-java: Fixed some bugs (by Henry Wang, #1840)
  * libtiled-java: Fixed tile offset value not being considered (by digitalhoax, #1863)
- Remove upstreamed tiled-1.1.0-empty-return.patch
* Fri Jan  5 2018 mvetter@suse.com
- Update to 1.1.1:
  * Fixed crash on load for template instances of non-tile objects
* Thu Jan  4 2018 mvetter@suse.com
- Update to 1.1.0:
  * Added support for infinite maps (by Ketan Gupta, #260)
  * Added support for Wang tiles and related tools (by Benjamin Trotter)
  * Added support for reusable object templates (by Mohamed Thabet)
  * Added icon for animation editor in the tileset editor (by Ketan Gupta, #1706)
  * Added ability to reorder terrain types (by Justin Jacobs, #1603)
  * Added support for custom input formats and TMX output to the --export-map command-line option
  * Added island RPG example based on Beach tileset by finalbossblues
  * Added file-related context menu actions to tileset tabs
  * Added support for exporting tilesets, including to Lua format (by Conrad Mercer, #1213)
  * Improved polygon node handles and drag behavior
  * Fixed %%executablepath variable for executables found in PATH (#1648)
  * Fixed Delete key to delete selected polygon nodes when appropriate (by Ketan Gupta, #1555)
  * Fixed crash when saving two new maps using the same file name (#1734)
  * Fixed selection rectangle's shadow offset when zooming (by Antoine Gersant, #1796)
  * Fixed potential crash after deleting object or group layers
  * Automapping: Don't fail if an input/inputnot layer isn't found
  * Automapping: Added a "StrictEmpty" flag to input layers
  * GMX plugin: Added support for defining views with objects (by William Taylor, #1621)
  * GMX plugin: Start counting default tile layer depth from 1000000 (#1814)
  * tBIN plugin: Added read/write support for the tBIN map format (by Chase Warrington, #1560)
  * libtiled-java: Generate classes from XSD, some fixes and build with Maven (by Mike Thomas, #1637)
  * libtiled-java: Added support for manipulating non-consecutive tile IDs in a tileset (by Stéphane Seng)
  * Python plugin: Adjusted example scripts to API changes (by spiiin, #1769)
  * plugin: Various changes (by Justin Jacobs, #1781)
  * TMW plugin: Removed since it is no longer needed
  * Updated translations
- Add tiled-1.1.0-empty-return.patch: Fix 'Program returns random data in a function'
* Tue Aug 29 2017 mvetter@suse.com
- Update to 1.0.3:
  * Fixed crash on reload map (#1659[1], #1694[2])
  * Fixed possible crash on undo/redo in collision editor (#1695[3])
  * Fixed tile replacement to add tileset when needed (by Mohamed Thabet, #1641[4])
  * Fixed the display of the image source property for tilesets
  * Fixed shortcut for 'Copy tile coordinates' (Alt+C) in Portuguese translation (by olueiro)
  * JSON plugin: Fixed reading of tileset column count
  * JSON plugin: Fixed reading of custom properties on tile collision object group
* Wed Jun 14 2017 mvetter@suse.com
- Update to 1.0.1:
  * Made the zoom level used in Tilesets view persistent
  * Fixed mixed up polygon and polyline icons (by Ketan Gupta, #1588[1])
  * Fixed reset of font size when using font dialog (#1596[2])
  * Fixed several issues with the Properties dock (#1583[3], #1611[4])
  * Fixed centering on object on layer with offset (#1600[5])
  * Fixed handling of symbolic links in Recent Files menu and Maps view (#1589[6])
  * Fixed labels for objects in grouped object layers
  * Reverted the file format version back to "1.0" and added "tiledversion" attribute
  * Lua plugin: Fixed group layers being exported with "imagelayer" type (#1595[7])
  * Added Korean translation (by miru2533 and SshipSunBee, #1604[8])
  * Updated Russian and Chinese translations
* Fri May 26 2017 mvetter@suse.com
- Update to 1.0.0:
  * Added support for editing external tilesets (#242)
  * Added a text object with configurable font and wrapping (#1429)
  * Added layer grouping (#1038)
  * Added Tile.type and inherit tile object properties from the tile (#436, #1248)
  * Added a start page
  * Added selection of underlying objects with Alt modifier (by Yuriy, #1491)
  * Added an option to disable safe writing of files (#1402, #1404)
  * Added invert selection action (by Leon Moctezuma, #1423)
  * Added support for isometric terrain overlays and tile collision objects (#419, #757)
  * Added 180-degree symmetry mode to terrain brush with Alt modifier
  * Added short and consistent map format names to use with --export-map (by Marce Coll, #1382)
  * Added Swap Tiles action (by Alexander Münch, #866)
  * Added tileset background color property (#227)
  * Added 60 degree tile rotation support for hexagonal maps (by Victor Nicolaichuk, #1447)
  * Added a check for duplicates when adding tiles (by Simião, #1227)
  * Added option to run commands from menu as well as edit them (by Ketan Gupta, #943)
  * Added custom shortcuts for commands (by Ketan Gupta, #1456)
  * Added optional ID and Position columns to objects view (by i-ka, #1462)
  * Added an executable picker for custom commands (by Ketan Gupta, #942)
  * Added marching ants effect on selected objects (by Mohamed Thabet, #1489)
  * Added all open tilesets to the Tilesets view
  * Added auto-show/hide all views (Clear View) action (by erem2k, #563)
  * Added minimap in the resizing dialog (by Yuriy, #1516)
  * Added drag-n-drop support in Layers view (#178)
  * Added support for storing object type definitions in JSON format (#1313)
  * Added cut/copy/paste actions for custom properties (#515)
  * Allow changing the tile of tile objects (by Mohamed Thabet, #409)
  * Allow selecting a folder to fix multiple broken links at once
  * Added support for dragging external tilesets into the Tilesets dock
  * Added support for dragging images into image collection tilesets
  * Write out Tiled version in TMX/JSON “version” attribute (#1416)
  * Remember last view on map also for closed files (#905)
  * Remember tileset zoom level in the tileset editor (by Artem Sharganov, #408)
  * Change current layer depending on selected objects (by Glavak, #1424)
  * Improved support for using Tiled on HiDpi screens
  * Improved the behavior of the tile selection tool
  * Made Ctrl+D duplicate objects instead of deleting them
  * Use an eye icon instead of a checkbox for layer visibility (by Ketan Gupta, #1127)
  * JSON tileset: Save width/height of individual tile images
  * Linux: Added MIME type for tileset files
  * Fixed hexagonal rotation of tile stamps (by Bdtrotte, #1476)
  * Fixed handling of broken tile references, which now render as a red marker
  * Fixed manual reloading of images for image collection tilesets
  * Fixed Offset Layers tool to wait until mouse is moved
  * Fixed current stamp to always update when a tile is clicked
  * Fixed handling of pinch gestures (#1305)
  * Fixed flipping a group of objects to work like expected (by Vitek1425, #1475)
  * Fixed stamp brush to work better on staggered maps (by Bdtrotte)
  * Fixed objects offsetting while resizing (by Acuion, #1518)
  * Fixed fill tool for hexagonal maps (#883)
  * Fixed potential crash in Terrain Brush
  * Windows: Fixed menus when using OpenGL in full screen mode (#1576)
  * Windows: Added Sticker Knight and Python example scripts to installer (#819)
  * Windows: Fixed bringing existing Tiled window to foreground (#1256)
  * AutoMapping: Fixed object groups always getting added
  * AutoMapping: Improved map boundary handling (by Stefan Beller, #1224)
  * AutoMapping: Apply custom properties set on output layers
  * terraingenerator: Made the amount of columns configurable
  * terraingenerator: Copy tile properties from the source tilesets
  * Added Ukrainian translation (by Olexandr Nesterenko)
  * Added Hungarian translation (by Balázs Úr)
  * Added Finnish translation (by ekeimaja)
  * Updated Bulgarian, Dutch, French, German, Russian, Spanish and Turkish translations
* Tue Mar  7 2017 mvetter@suse.com
- Update to 0.18.2:
  * Fixed crash when deleting multiple selected objects
  * Fixed crash when moving multiple selected objects to another object layer
  * Fixed updating of values displayed in Objects and Layers views
  * GmxPlugin: Added support for image collection tilesets
  * Object Types Editor: Improved behavior when adding new types
  * Linux: Fixed shipping of image format plugins in AppImage releases
* Thu Feb  2 2017 jengelh@inai.de
- Trim filler words from description
* Fri Jan 27 2017 mvetter@suse.com
- Update to 0.18.1:
  * Fixed terrain brush for isometric staggered maps (by Clyde)
  * Fixed crash when resizing map causes objects to get removed
  * Fixed crash when duplicating an object layer
  * Fixed position of image layer after Resize or Offset Map
  * Fixed the quality of the minimap on HiDpi displays
  * Fixed Alt-drag behavior to not override resize handles
  * When adding a new layer, insert it above the current one
  * GmxPlugin: Fixed positioning for non-tile objects and support scaling
  * GmxPlugin: Export tile objects without a type as tiles
  * GmxPlugin: Support horizontal and vertical flipping
  * Updated Chinese translation (by Clyde)
* Tue Dec 20 2016 mvetter@suse.com
- Fix plugin detection:
  We need USE_FHS_PLUGIN_PATH=yes so tiled finds the plugins and
  doesn't look relative to the executables path.
  Without this exporting to lua, json etc never worked.
* Tue Dec 20 2016 mvetter@suse.com
- Update to version 0.18.0:
  * Added Layer via Copy/Cut actions
  * Added support for Paste in Place action for tile layers
  * Added context menu to change custom property type (by Dmitry Hrabrov)
  * Added support for higher precision for custom floating point properties
  * Added %%mappath variable to commands (by Jack Roper)
  * Added snapping to pixels (by Mamed Ibrahimov)
  * Added right-click to clear the tile selection
  * Added a context menu action to reset the size of tile objects
  * Added exporter for Game Maker Studio room files (by Jones Blunt)
  * Added Move Up/Down buttons to Objects view (by iskolbin)
  * Added pixel coordinates to status bar for object tools (by iskolbin)
  * Added Sticker Knight platformer example (by Ponywolf)
  * tmxrasterizer: Added --size argument and support local file URLs
  * tmxrasterizer: Use smooth pixmap transform by default
  * Linux: Register tmxrasterizer as thumbnail generator for TMX files
  * Allow scrolling past map edges with mouse wheel
  * Enabled HiDpi scaling and improved the quality of some icons
  * Reversed the order of the objects in the Objects view
  * JSON plugin: Added Node.js support to the JavaScript export
  * Updated TMX schema definition (by assofohdz)
  * Fixed unfinished objects getting saved
  * Fixed OpenGL rendering mode when application is scaled (HiDpi screens)
  * Fixed Remove and Rename actions for predefined properties
  * Windows: Fixed console output
  * libtiled-java: Use Maven, deploy to OSSRH and code updates (by Mike Thomas)
  * libtiled-java: Added a basic isometric renderer (by Mike Thomas)
  * Updated Brazilian Portuguese, Chinese, Czech, Dutch, Hebrew, Norwegian Bokmål and Spanish translations
  See: http://discourse.mapeditor.org/t/tiled-0-18-0-released/1897
- Add tiled.thumbnailer
* Wed Oct 12 2016 mailaender@opensuse.org
- Add icon/desktop/mime macros
- Install appdata for https://en.opensuse.org/openSUSE:AppStore
- Update to version 0.17.0
  * Added a platform-independent theme, which can be dark (#786)
  * Added Paste in Place action for objects (#1257)
  * Added custom property type 'color' (#1275)
  * Added custom property type 'file' (#1278)
  * Added option for removing invisible objects in resize dialog (#1032, by Mamed Ibrahimov)
  * Added support for editing multi-line string properties (#205)
  * Added %%layername and %%objectid to available command variables
  * Added support for scrolling in tileset view with middle mouse button (#1050, with Will Luongo)
  * Added a rectangle erase mode to the eraser (#1297)
  * Added export to Defold .tilemap files (#1316, by Nikita Razdobreev)
  * Added simple full screen mode
  * Added "Copy File Path" and "Open Containing Folder" actions to tab context menu
  * Added warning when saving with the wrong file extension
  * Added color picker for setting transparent color of a tileset (#1173, by Ava Brumfield)
  * Various object selection tool improvements
  * Allow creating rectangle/ellipse objects in any direction (#1300)
  * Enabled nested views and grouped dragging for stacked views (#1291)
  * Fixed updating object drag cursor when exiting resize handles (#1277)
  * Fixed tile animations to stay in sync when changing them (#1288)
  * Fixed preservation of tile meta-data when tileset width is changed (#1315)
  * Updated Bulgarian, Dutch, German, Norwegian Bokmål, Russian, Spanish and Turkish translations
  * JSON plugin: Fixed loading of custom properties on terrains
  * Lua plugin: Fixed missing export of object layer drawing order
  * Fixed tile index adjustment when tileset image changes width
  * Fixed --export-map [format] option
  * Fixed shortcuts for some tools when language is set to Dutch
  * Fixed a painting related bug affecting the top edge after AutoMapping
* Fri May 13 2016 rpm@fthiessen.de
- Update to version 0.16.1
  * Bugfix release, some crashed are fixed.
* Mon May  2 2016 rpm@fthiessen.de
- Update to version 0.16.0
- Minor spec cleanup
* Wed Jun 17 2015 roman@priesol.net
- update to version 0.12.3
* Sun Jan  4 2015 bemyak@gmail.com
- update to version 0.10.2
* Wed Nov 13 2013 mailaender@opensuse.org
- update to version 0.9.1
- spec and file cleanup
- removed desktop file and icon (now included)
- https://en.opensuse.org/SourceUrls
- separated GUI tool, library and cli tools
* Tue Feb  5 2013 ablu.erikschilling@googlemail.com
- fixed qt4->qt
* Tue Feb  5 2013 ablu.erikschilling@googlemail.com
- Removed conflict line
* Fri Feb  1 2013 ablu.erikschilling@googlemail.com
- Added conflict line
* Mon Jan 28 2013 ablu.erikschilling@googlemail.com
- Added obsolete line
* Sat Jan 12 2013 ablu.erikschilling@googlemail.com
- New upstream release 0.9.0
- Dropped now obsolete patches and files
* Mon Sep  3 2012 ablu.erikschilling@googlemail.com
- Added note about which parts are licensed with which license.
- Made sure that the copy of zlib inside of the source is removed.
- Fixed handling of locales (using %%%%find_lang).
- Avoided plain asterisks in %%%%files.
- Made description clear about containing the tmxviewer.
* Sun Sep  2 2012 ablu.erikschilling@googlemail.com
- First version for official fedora repos.
* Fri May 11 2012 ablu.erikschilling@googlemail.com
- Copied package to obs, fixed problems occurring there.
